@@ -28,8 +28,8 @@ module Jekyll
           FileUtils.mkdir_p new_blog_path
           if preserve_source_location?(new_blog_path, options)
             Jekyll.logger.error "Conflict:", "#{new_blog_path} exists and is not empty."
-            Jekyll.logger.abort_with "", "Ensure #{new_blog_path} is empty or else " \
-                      "try again with `--force` to proceed and overwrite any files."
+            Jekyll.logger.abort_with "", "Ensure #{new_blog_path} is empty or else try again " \
+                                         "with `--force` to proceed and overwrite any files."
           end
 
           if options["blank"]
@@ -41,10 +41,16 @@ module Jekyll
           after_install(new_blog_path, options)
         end
 
+        def blank_template
+          File.expand_path("../../blank_template", __dir__)
+        end
+
         def create_blank_site(path)
+          FileUtils.cp_r blank_template + "/.", path
+          FileUtils.chmod_R "u+w", path
+
           Dir.chdir(path) do
-            FileUtils.mkdir(%w(_layouts _posts _drafts))
-            FileUtils.touch("index.html")
+            FileUtils.mkdir(%w(_data _drafts _includes _posts))
           end
         end
 
@@ -62,58 +68,49 @@ module Jekyll
         private
 
         def gemfile_contents
-          <<-RUBY
-source "https://rubygems.org"
+          <<~RUBY
+            source "https://rubygems.org"
+            # Hello! This is where you manage which Jekyll version is used to run.
+            # When you want to use a different version, change it below, save the
+            # file and run `bundle install`. Run Jekyll with `bundle exec`, like so:
+            #
+            #     bundle exec jekyll serve
+            #
+            # This will help ensure the proper Jekyll version is running.
+            # Happy Jekylling!
+            gem "jekyll", "~> #{Jekyll::VERSION}"
+            # This is the default theme for new Jekyll sites. You may change this to anything you like.
+            gem "minima", "~> 2.5"
+            # If you want to use GitHub Pages, remove the "gem "jekyll"" above and
+            # uncomment the line below. To upgrade, run `bundle update github-pages`.
+            # gem "github-pages", group: :jekyll_plugins
+            # If you have any plugins, put them here!
+            group :jekyll_plugins do
+              gem "jekyll-feed", "~> 0.12"
+            end
 
-# Hello! This is where you manage which Jekyll version is used to run.
-# When you want to use a different version, change it below, save the
-# file and run `bundle install`. Run Jekyll with `bundle exec`, like so:
-#
-#     bundle exec jekyll serve
-#
-# This will help ensure the proper Jekyll version is running.
-# Happy Jekylling!
-gem "jekyll", "~> #{Jekyll::VERSION}"
+            # Windows and JRuby does not include zoneinfo files, so bundle the tzinfo-data gem
+            # and associated library.
+            platforms :mingw, :x64_mingw, :mswin, :jruby do
+              gem "tzinfo", ">= 1", "< 3"
+              gem "tzinfo-data"
+            end
 
-# This is the default theme for new Jekyll sites. You may change this to anything you like.
-gem "minima", "~> 2.0"
+            # Performance-booster for watching directories on Windows
+            gem "wdm", "~> 0.1.1", :platforms => [:mingw, :x64_mingw, :mswin]
 
-# If you want to use GitHub Pages, remove the "gem "jekyll"" above and
-# uncomment the line below. To upgrade, run `bundle update github-pages`.
-# gem "github-pages", group: :jekyll_plugins
-
-# If you have any plugins, put them here!
-group :jekyll_plugins do
-  gem "jekyll-feed", "~> 0.6"
-end
-
-# Windows does not include zoneinfo files, so bundle the tzinfo-data gem
-# and associated library.
-install_if -> { RUBY_PLATFORM =~ %r!mingw|mswin|java! } do
-  gem "tzinfo", "~> 1.2"
-  gem "tzinfo-data"
-end
-
-# Performance-booster for watching directories on Windows
-gem "wdm", "~> 0.1.0", :install_if => Gem.win_platform?
-
-# kramdown v2 ships without the gfm parser by default. If you're using
-# kramdown v1, comment out this line.
-gem "kramdown-parser-gfm"
-
-RUBY
+            # Lock `http_parser.rb` gem to `v0.6.x` on JRuby builds since newer versions of the gem
+            # do not have a Java counterpart.
+            gem "http_parser.rb", "~> 0.6.0", :platforms => [:jruby]
+          RUBY
         end
 
         def create_site(new_blog_path)
           create_sample_files new_blog_path
 
-          File.open(File.expand_path(initialized_post_name, new_blog_path), "w") do |f|
-            f.write(scaffold_post_content)
-          end
+          File.write(File.expand_path(initialized_post_name, new_blog_path), scaffold_post_content)
 
-          File.open(File.expand_path("Gemfile", new_blog_path), "w") do |f|
-            f.write(gemfile_contents)
-          end
+          File.write(File.expand_path("Gemfile", new_blog_path), gemfile_contents)
         end
 
         def preserve_source_location?(path, options)
