@@ -7,9 +7,17 @@ module Jekyll
         @obj.doc.data["layout"]
       end
 
+      def date
+        @obj.doc.date
+      end
+
       def excerpt
         nil
       end
+
+      def name
+        @obj.doc.data["name"] || @obj.doc.basename
+      end
     end
   end
 end
