@@ -10,12 +10,12 @@ class TestAnsi < JekyllUnitTest
 
     Jekyll::Utils::Ansi::COLORS.each_key do |color|
       should "respond_to? #{color}" do
-        assert @subject.respond_to?(color)
+        assert_respond_to(@subject, color)
       end
     end
 
     should "be able to strip colors" do
-      assert_equal @subject.strip(@subject.yellow(@subject.red("hello"))), "hello"
+      assert_equal "hello", @subject.strip(@subject.yellow(@subject.red("hello")))
     end
 
     should "be able to detect colors" do
