@@ -15,7 +15,7 @@ class TestSite < JekyllUnitTest
     @site.posts.docs.concat(PostReader.new(@site).read_posts(""))
     posts = Dir[source_dir("_posts", "**", "*")]
     posts.delete_if do |post|
-      File.directory?(post) && !(post =~ Document::DATE_FILENAME_MATCHER)
+      File.directory?(post) && post !~ Document::DATE_FILENAME_MATCHER
     end
   end
 
@@ -31,30 +31,26 @@ class TestSite < JekyllUnitTest
     end
 
     should "have an array for plugins if passed as a string" do
-      site = Site.new(site_configuration({ "plugins_dir" => "/tmp/plugins" }))
-      array = Utils::Platforms.windows? ? ["C:/tmp/plugins"] : ["/tmp/plugins"]
+      site = Site.new(site_configuration("plugins_dir" => "/tmp/plugins"))
+      array = [temp_dir("plugins")]
       assert_equal array, site.plugins
     end
 
     should "have an array for plugins if passed as an array" do
-      site = Site.new(site_configuration({
-        "plugins_dir" => ["/tmp/plugins", "/tmp/otherplugins"],
-      }))
-      array = if Utils::Platforms.windows?
-                ["C:/tmp/plugins", "C:/tmp/otherplugins"]
-              else
-                ["/tmp/plugins", "/tmp/otherplugins"]
-              end
+      site = Site.new(site_configuration(
+                        "plugins_dir" => ["/tmp/plugins", "/tmp/otherplugins"]
+                      ))
+      array = [temp_dir("plugins"), temp_dir("otherplugins")]
       assert_equal array, site.plugins
     end
 
     should "have an empty array for plugins if nothing is passed" do
-      site = Site.new(site_configuration({ "plugins_dir" => [] }))
+      site = Site.new(site_configuration("plugins_dir" => []))
       assert_equal [], site.plugins
     end
 
     should "have the default for plugins if nil is passed" do
-      site = Site.new(site_configuration({ "plugins_dir" => nil }))
+      site = Site.new(site_configuration("plugins_dir" => nil))
       assert_equal [source_dir("_plugins")], site.plugins
     end
 
@@ -64,32 +60,70 @@ class TestSite < JekyllUnitTest
     end
 
     should "expose baseurl passed in from config" do
-      site = Site.new(site_configuration({ "baseurl" => "/blog" }))
+      site = Site.new(site_configuration("baseurl" => "/blog"))
       assert_equal "/blog", site.baseurl
     end
 
     should "only include theme includes_path if the path exists" do
-      site = fixture_site({ "theme" => "test-theme" })
+      site = fixture_site("theme" => "test-theme")
       assert_equal [source_dir("_includes"), theme_dir("_includes")],
-        site.includes_load_paths
+                   site.includes_load_paths
 
       allow(File).to receive(:directory?).with(theme_dir("_sass")).and_return(true)
       allow(File).to receive(:directory?).with(theme_dir("_layouts")).and_return(true)
       allow(File).to receive(:directory?).with(theme_dir("_includes")).and_return(false)
-      site = fixture_site({ "theme" => "test-theme" })
+      site = fixture_site("theme" => "test-theme")
       assert_equal [source_dir("_includes")], site.includes_load_paths
     end
+
+    should "configure cache_dir" do
+      fixture_site.process
+      assert File.directory?(source_dir(".jekyll-cache", "Jekyll", "Cache"))
+      assert File.directory?(source_dir(".jekyll-cache", "Jekyll", "Cache", "Jekyll--Cache"))
+    end
+
+    should "use .jekyll-cache directory at source as cache_dir by default" do
+      site = Site.new(default_configuration)
+      assert_equal File.join(site.source, ".jekyll-cache"), site.cache_dir
+    end
+
+    should "have the cache_dir hidden from Git" do
+      site = fixture_site
+      assert_equal site.source, source_dir
+      assert_exist source_dir(".jekyll-cache", ".gitignore")
+      assert_equal(
+        "# ignore everything in this directory\n*\n",
+        File.binread(source_dir(".jekyll-cache", ".gitignore"))
+      )
+    end
+
+    should "load config file from theme-gem as Jekyll::Configuration instance" do
+      site = fixture_site("theme" => "test-theme")
+      assert_instance_of Jekyll::Configuration, site.config
+      assert_equal "Hello World", site.config["title"]
+    end
+
+    context "with a custom cache_dir configuration" do
+      should "have the custom cache_dir hidden from Git" do
+        site = fixture_site("cache_dir" => "../../custom-cache-dir")
+        refute_exist File.expand_path("../../custom-cache-dir/.gitignore", site.source)
+        assert_exist source_dir("custom-cache-dir", ".gitignore")
+        assert_equal(
+          "# ignore everything in this directory\n*\n",
+          File.binread(source_dir("custom-cache-dir", ".gitignore"))
+        )
+      end
+    end
   end
+
   context "creating sites" do
     setup do
       @site = Site.new(site_configuration)
-      @num_invalid_posts = 4
+      @num_invalid_posts = 6
     end
 
     teardown do
-      if defined?(MyGenerator)
-        self.class.send(:remove_const, :MyGenerator)
-      end
+      self.class.send(:remove_const, :MyGenerator) if defined?(MyGenerator)
     end
 
     should "have an empty tag hash by default" do
@@ -181,7 +215,7 @@ class TestSite < JekyllUnitTest
 
       # simulate destination file deletion
       File.unlink dest
-      refute File.exist?(dest)
+      refute_path_exists(dest)
 
       sleep 1
       @site.process
@@ -213,6 +247,7 @@ class TestSite < JekyllUnitTest
       @site.process
       # exclude files in symlinked directories here and insert them in the
       # following step when not on Windows.
+      # rubocop:disable Style/WordArray
       sorted_pages = %w(
         %#\ +.md
         .htaccess
@@ -226,20 +261,26 @@ class TestSite < JekyllUnitTest
         environment.html
         exploit.md
         foo.md
+        foo.md
         humans.txt
         index.html
         index.html
         info.md
+        main.css.map
         main.scss
         properties.html
         sitemap.xml
         static_files.html
+        test-styles.css.map
+        test-styles.scss
+        trailing-dots...md
       )
+      # rubocop:enable Style/WordArray
       unless Utils::Platforms.really_windows?
         # files in symlinked directories may appear twice
-        sorted_pages.push("main.scss", "symlinked-file").sort!
+        sorted_pages.push("main.css.map", "main.scss", "symlinked-file").sort!
       end
-      assert_equal sorted_pages, @site.pages.map(&:name)
+      assert_equal sorted_pages, @site.pages.map(&:name).sort!
     end
 
     should "read posts" do
@@ -257,12 +298,12 @@ class TestSite < JekyllUnitTest
 
     should "read pages with YAML front matter" do
       abs_path = File.expand_path("about.html", @site.source)
-      assert_equal true, Utils.has_yaml_header?(abs_path)
+      assert Utils.has_yaml_header?(abs_path)
     end
 
     should "enforce a strict 3-dash limit on the start of the YAML front matter" do
       abs_path = File.expand_path("pgp.key", @site.source)
-      assert_equal false, Utils.has_yaml_header?(abs_path)
+      refute Utils.has_yaml_header?(abs_path)
     end
 
     should "expose jekyll version to site payload" do
@@ -279,7 +320,7 @@ class TestSite < JekyllUnitTest
 
       posts = Dir[source_dir("**", "_posts", "**", "*")]
       posts.delete_if do |post|
-        File.directory?(post) && !(post =~ Document::DATE_FILENAME_MATCHER)
+        File.directory?(post) && post !~ Document::DATE_FILENAME_MATCHER
       end
       categories = %w(
         2013 bar baz category foo z_category MixedCase Mixedcase publish_test win
@@ -305,9 +346,9 @@ class TestSite < JekyllUnitTest
 
       should "raise for bad frontmatter if strict_front_matter is set" do
         site = Site.new(site_configuration(
-          "collections"         => ["broken"],
-          "strict_front_matter" => true
-        ))
+                          "collections"         => ["broken"],
+                          "strict_front_matter" => true
+                        ))
         assert_raises(Psych::SyntaxError) do
           site.process
         end
@@ -315,9 +356,9 @@ class TestSite < JekyllUnitTest
 
       should "not raise for bad frontmatter if strict_front_matter is not set" do
         site = Site.new(site_configuration(
-          "collections"         => ["broken"],
-          "strict_front_matter" => false
-        ))
+                          "collections"         => ["broken"],
+                          "strict_front_matter" => false
+                        ))
         site.process
       end
     end
@@ -412,9 +453,9 @@ class TestSite < JekyllUnitTest
 
         bad_processor = "Custom::Markdown"
         s = Site.new(site_configuration(
-          "markdown"    => bad_processor,
-          "incremental" => false
-        ))
+                       "markdown"    => bad_processor,
+                       "incremental" => false
+                     ))
         assert_raises Jekyll::Errors::FatalException do
           s.process
         end
@@ -433,9 +474,9 @@ class TestSite < JekyllUnitTest
       should "throw FatalException at process time" do
         bad_processor = "not a processor name"
         s = Site.new(site_configuration(
-          "markdown"    => bad_processor,
-          "incremental" => false
-        ))
+                       "markdown"    => bad_processor,
+                       "incremental" => false
+                     ))
         assert_raises Jekyll::Errors::FatalException do
           s.process
         end
@@ -489,8 +530,8 @@ class TestSite < JekyllUnitTest
         site.process
 
         file_content = SafeYAML.load_file(File.join(
-          source_dir, "_data", "categories", "dairy.yaml"
-        ))
+                                            source_dir, "_data", "categories", "dairy.yaml"
+                                          ))
 
         assert_equal site.data["categories"]["dairy"], file_content
         assert_equal(
@@ -504,8 +545,8 @@ class TestSite < JekyllUnitTest
         site.process
 
         file_content = SafeYAML.load_file(File.join(
-          source_dir, "_data", "categories.01", "dairy.yaml"
-        ))
+                                            source_dir, "_data", "categories.01", "dairy.yaml"
+                                          ))
 
         assert_equal site.data["categories01"]["dairy"], file_content
         assert_equal(
@@ -536,9 +577,9 @@ class TestSite < JekyllUnitTest
 
     context "manipulating the Jekyll environment" do
       setup do
-        @site = Site.new(site_configuration({
-          "incremental" => false,
-        }))
+        @site = Site.new(site_configuration(
+                           "incremental" => false
+                         ))
         @site.process
         @page = @site.pages.find { |p| p.name == "environment.html" }
       end
@@ -550,9 +591,9 @@ class TestSite < JekyllUnitTest
       context "in production" do
         setup do
           ENV["JEKYLL_ENV"] = "production"
-          @site = Site.new(site_configuration({
-            "incremental" => false,
-          }))
+          @site = Site.new(site_configuration(
+                             "incremental" => false
+                           ))
           @site.process
           @page = @site.pages.find { |p| p.name == "environment.html" }
         end
@@ -571,25 +612,29 @@ class TestSite < JekyllUnitTest
       should "set no theme if config is not set" do
         expect($stderr).not_to receive(:puts)
         expect($stdout).not_to receive(:puts)
-        site = fixture_site({ "theme" => nil })
+        site = fixture_site("theme" => nil)
         assert_nil site.theme
       end
 
       should "set no theme if config is a hash" do
         output = capture_output do
-          site = fixture_site({ "theme" => {} })
+          site = fixture_site("theme" => {})
           assert_nil site.theme
         end
-        expected_msg = "Theme: value of 'theme' in config should be String " \
-          "to use gem-based themes, but got Hash\n"
+        expected_msg = "Theme: value of 'theme' in config should be String to use " \
+                       "gem-based themes, but got Hash\n"
         assert_includes output, expected_msg
       end
 
       should "set a theme if the config is a string" do
         [:debug, :info, :warn, :error].each do |level|
-          expect(Jekyll.logger.writer).not_to receive(level)
+          if level == :info
+            expect(Jekyll.logger.writer).to receive(level)
+          else
+            expect(Jekyll.logger.writer).not_to receive(level)
+          end
         end
-        site = fixture_site({ "theme" => "test-theme" })
+        site = fixture_site("theme" => "test-theme")
         assert_instance_of Jekyll::Theme, site.theme
         assert_equal "test-theme", site.theme.name
       end
@@ -616,9 +661,9 @@ class TestSite < JekyllUnitTest
 
     context "incremental build" do
       setup do
-        @site = Site.new(site_configuration({
-          "incremental" => true,
-        }))
+        @site = Site.new(site_configuration(
+                           "incremental" => true
+                         ))
         @site.read
       end
 
@@ -668,5 +713,50 @@ class TestSite < JekyllUnitTest
         refute_equal mtime1, mtime2 # must be regenerated
       end
     end
+
+    context "#in_cache_dir method" do
+      setup do
+        @site = Site.new(
+          site_configuration(
+            "cache_dir" => "../../custom-cache-dir"
+          )
+        )
+      end
+
+      should "create sanitized paths within the cache directory" do
+        assert_equal File.join(@site.source, "custom-cache-dir"), @site.cache_dir
+        assert_equal(
+          File.join(@site.source, "custom-cache-dir", "foo.md.metadata"),
+          @site.in_cache_dir("../../foo.md.metadata")
+        )
+      end
+    end
+  end
+
+  context "site process phases" do
+    should "return nil as documented" do
+      site = fixture_site
+      [:reset, :read, :generate, :render, :cleanup, :write].each do |phase|
+        assert_nil site.send(phase)
+      end
+    end
+  end
+
+  context "static files in a collection" do
+    should "be exposed via site instance" do
+      site = fixture_site("collections" => ["methods"])
+      site.read
+
+      assert_includes site.static_files.map(&:relative_path), "_methods/extensionless_static_file"
+    end
+
+    should "not be revisited in `Site#each_site_file`" do
+      site = fixture_site("collections" => { "methods" => { "output" => true } })
+      site.read
+
+      visited_files = []
+      site.each_site_file { |file| visited_files << file }
+      assert_equal visited_files.count, visited_files.uniq.count
+    end
   end
 end
